@@ -15,7 +15,6 @@ from ...exception import APICallFailed as BaseAPICallFailed
 from ...exception import ParamMismatch, ParamMissing
 from ...typings import T_ForwardMsg, UserStr
 from ..api import API as BaseAPI
-from ..api import register_api
 from ..decorators import Overload, debug_log, export, strict
 from ..group import Group as BaseGroup
 from ..help_doc import descript
@@ -39,14 +38,11 @@ def file2str(file: str | bytes | BytesIO | Path) -> str:
 
 
 async def _extract_user_str_args(us: UserStr) -> tuple[int, "Message", str | None]:
-    user_id = int(us)
     args = us.extract_args()
     assert len(args) > 0
     content = cast("Message", await as_msg(args.pop(0)))
-    name = None
-    if args:
-        name = (await as_msg(args.pop(0))).extract_plain_text()
-    return user_id, content, name
+    name = (await as_msg(args.pop(0))).extract_plain_text() if args else None
+    return int(us), content, name
 
 
 async def convert_forward(msgs: T_ForwardMsg) -> "Message":
@@ -78,7 +74,6 @@ with contextlib.suppress(ImportError):
         Bot,
         Message,
         MessageEvent,
-        MessageSegment,
     )
 
     class APICallFailed(BaseAPICallFailed, ActionFailed): ...
@@ -105,8 +100,7 @@ with contextlib.suppress(ImportError):
         async def send_fwd(self, msgs: T_ForwardMsg) -> Result:
             return await self.api.send_grp_fwd(self.uid, msgs)
 
-    @register_api(Adapter)
-    class API(BaseAPI[Bot, MessageEvent]):
+    class API(BaseAPI[Bot, MessageEvent], adapter=Adapter):
         __slots__ = ()
 
         @classmethod
@@ -121,7 +115,7 @@ with contextlib.suppress(ImportError):
         )
         @debug_log
         @override
-        async def get_platform(self) -> str:
+        async def get_platform(self: BaseAPI[Bot, MessageEvent]) -> str:
             data = await self.bot.get_version_info()
             return f"[{self.bot.type}] {data['app_name']} {data['app_version']}"
 
@@ -155,7 +149,7 @@ with contextlib.suppress(ImportError):
             except BaseException as e:
                 res = {"error": e}
                 msg = (
-                    f"用户(<c>{escape_tag(self.uid)}<c>) "
+                    f"用户(<c>{self.uid}<c>) "
                     f"调用 api <y>{escape_tag(api)}</y> 时发生错误: "
                     f"<r>{escape_tag(repr(e))}</r>"
                 )
@@ -206,7 +200,7 @@ with contextlib.suppress(ImportError):
         async def send_grp_fwd(self, gid: int | str, msgs: T_ForwardMsg) -> Result:
             return await self.call_api(
                 "send_group_forward_msg",
-                user_id=int(gid),
+                group_id=int(gid),
                 messages=await convert_forward(msgs),
             )
 
@@ -283,13 +277,13 @@ with contextlib.suppress(ImportError):
 
         @descript(
             description="通过合并转发ID获取合并转发消息",
-            parameters=dict(msg_id="需要获取的合并转发ID，可通过getcqcode获取"),
+            parameters=dict(msg_id="需要获取的合并转发ID，可通过getraw获取"),
             result="获取到的合并转发消息列表",
         )
         @export
         @debug_log
         @strict
-        async def get_fwd(self, msg_id: int) -> list[Message]:
+        async def get_fwd(self, msg_id: int | str) -> list[Message]:
             logger.debug(f"[OneBot V11] 获取合并转发消息: {msg_id=}")
             res = await self.call_api(
                 "get_forward_msg",
@@ -298,29 +292,6 @@ with contextlib.suppress(ImportError):
             )
             return [Message(i["raw_message"]) for i in res["messages"]]
 
-        @descript(
-            description="[NapCat] 发送带有外显文本的图片",
-            parameters=dict(
-                summary="外显文本",
-                url="图片链接，默认为当前环境gurl",
-            ),
-        )
-        @debug_log
-        @strict
-        async def img_summary(self, summary: str, url: str | None = None) -> None:
-            if url is None:
-                from ...context import Context
-
-                url = Context.get_context(self.session).ctx.get("gurl")
-
-            if not url:
-                raise ParamMissing("无效 url")
-
-            logger.debug(f"[NapCat] 创建图片外显: <y>{summary}</y>, <c>{url}</c>")
-            seg = MessageSegment.image(url)
-            seg.data["summary"] = summary
-            await self.native_send(Message(seg))
-
         @descript(
             description="设置群名片",
             parameters=dict(
@@ -438,7 +409,6 @@ with contextlib.suppress(ImportError):
                 timeout="上传文件超时时长，单位秒",
             ),
         )
-        @debug_log
         @strict
         async def send_group_file(
             self,
@@ -472,7 +442,6 @@ with contextlib.suppress(ImportError):
                 timeout="上传文件超时时长，单位秒",
             ),
         )
-        @debug_log
         @strict
         async def send_private_file(
             self,
@@ -503,7 +472,6 @@ with contextlib.suppress(ImportError):
                 timeout="上传文件超时时长，单位秒",
             ),
         )
-        @debug_log
         @strict
         async def send_file(
             self,
@@ -582,7 +550,7 @@ with contextlib.suppress(ImportError):
             if m is None:
                 raise APICallFailed("Markdown 消息发送失败: 无法提取 res_id")
 
-            res = await send("forward", {"id": m.group(1)})
+            res = await send("forward", {"id": m[1]})
             if res.error:
                 raise APICallFailed("Markdown 消息发送失败") from res.error
 
