@@ -1,8 +1,10 @@
-from collections.abc import Callable, Generator
-from typing import Any, ClassVar, NamedTuple, Self, cast
+import functools
+from collections.abc import Generator
+from typing import ClassVar, NamedTuple, Self
 
 from ..typings import T_Context
 from .help_doc import MethodDescription
+from .user_const_var import BUILTINS_KEY, DEFAULT_BUILTINS
 from .utils import get_method_description, is_export_method
 
 
@@ -14,16 +16,18 @@ class _Desc(NamedTuple):
 
 
 class Interface:
+    __slots__ = ("__builtins", "__context", "__exported")
+
     __inst_name__: ClassVar[str] = "interface"
-    __export_method__: ClassVar[list[str]] = []
-    __method_description__: ClassVar[dict[str, MethodDescription]] = {}
-
-    __slots__ = ("__context", "__exported")
+    __export_method__: ClassVar[set[str]] = set()
+    __method_description__: ClassVar[set[MethodDescription]] = set()
 
+    __builtins: dict[str, object] | None
     __context: T_Context | None
     __exported: set[str]
 
     def __init__(self, context: T_Context | None = None) -> None:
+        self.__builtins = DEFAULT_BUILTINS.copy() if context is not None else None
         self.__context = context
         self.__exported = set()
 
@@ -35,21 +39,21 @@ class Interface:
 
         if cls.__inst_name__ == Interface.__inst_name__:
             cls.__inst_name__ = cls.__name__.lower()  # pragma: no cover
-        cls.__export_method__ = [
+        cls.__export_method__ = {
             name for name, value in cls.__dict__.items() if is_export_method(value)
-        ]
+        }
         cls.__method_description__ = {
-            name: desc
-            for name, value in cls.__dict__.items()
+            desc
+            for value in cls.__dict__.values()
             if (desc := get_method_description(value))
         }
 
-    def _export(self, key: str, val: Any) -> None:
-        if self.__context is None:  # pragma: no cover
+    def _export(self, key: str, val: object) -> None:
+        if self.__builtins is None:  # pragma: no cover
             raise TypeError(
                 f"Interface class {type(self).__name__!r} not allowed to export"
             )
-        self.__context[key] = val
+        self.__builtins[key] = val
         self.__exported.add(key)
 
     def export(self) -> None:
@@ -58,13 +62,17 @@ class Interface:
             self._export(name, getattr(self, name))
 
     def __enter__(self) -> Self:
+        assert self.__context is not None
+        assert self.__builtins is not None
+
         self.export()
+        self.__context[BUILTINS_KEY] = self.__builtins
         return self
 
     def __exit__(self, *_: object) -> bool:
-        if self.__context is not None:
+        if _builtins := self.__builtins:
             for name in self.__exported:
-                self.__context.pop(name, None)
+                _builtins.pop(name, None)
         return False
 
     async def __aenter__(self) -> Self:
@@ -75,29 +83,27 @@ class Interface:
 
     @classmethod
     def _get_export_method(cls) -> Generator[str, None, None]:
-        for c in reversed(cls.mro()):
-            if issubclass(c, Interface):
-                yield from c.__export_method__
-
-    @classmethod
-    def _iter_method_description(cls) -> Generator[_Desc, None, None]:
-        for func_name, desc in cls.__method_description__.items():
-            func = cast(Callable[..., Any], getattr(cls, func_name))
-            is_export = is_export_method(func)
-            yield _Desc(
-                inst_name=cls.__inst_name__,
-                func_name=func_name,
-                is_export=is_export,
-                description=desc.format(),
-            )
+        yield from functools.reduce(
+            set[str].union,
+            (c.__export_method__ for c in cls.mro() if issubclass(c, Interface)),
+            set(),
+        )
 
     @classmethod
     def get_all_description(cls) -> tuple[list[str], list[str]]:
         method_dict: dict[str, _Desc] = {}
-        for c in cls.mro():
-            if issubclass(c, Interface):
-                for desc in c._iter_method_description():  # noqa: SLF001
-                    method_dict.setdefault(desc.func_name, desc)
+
+        c: type[Interface]
+        for c in filter(lambda c: issubclass(c, Interface), cls.mro()):
+            for d in c.__method_description__:
+                desc = _Desc(
+                    inst_name=cls.__inst_name__,
+                    func_name=d.name,
+                    is_export=is_export_method(d.call),
+                    description=d.format(),
+                )
+                method_dict.setdefault(desc.func_name, desc)
+
         methods = sorted(
             method_dict.values(),
             key=lambda x: (1 - x.is_export, x.inst_name, x.func_name),
