@@ -1,5 +1,3 @@
-# ruff: noqa: S101
-
 import base64
 from contextlib import AsyncExitStack
 from typing import Any
@@ -13,7 +11,11 @@ from nonebot.internal.params import DependsInner
 from nonebug import App
 
 from .fake.common import ensure_context, fake_img_bytes, fake_user_id
-from .fake.onebot11 import fake_v11_bot, fake_v11_group_message_event
+from .fake.onebot11 import (
+    ensure_v11_session_cache,
+    fake_v11_bot,
+    fake_v11_group_message_event,
+)
 
 
 def parse_handler_dependent(depends: DependsInner) -> Dependent[Any]:
@@ -24,12 +26,7 @@ def parse_handler_dependent(depends: DependsInner) -> Dependent[Any]:
     )
 
 
-code_test_extract_code = (
-    "print(" + MessageSegment.at(111) + ")\nprint(" + MessageSegment.image(b"") + ")\n"
-)
-
-
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_extract_code(app: App) -> None:
     from nonebot_plugin_exe_code.matchers.depends import _extract_code
 
@@ -53,12 +50,13 @@ async def test_extract_code(app: App) -> None:
         state = {}
         stack = AsyncExitStack()
 
-        with ensure_context(bot, event):
-            result = await dependent(bot=bot, event=event, state=state, stack=stack)
-            assert result == expected
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                result = await dependent(bot=bot, event=event, state=state, stack=stack)
+        assert result == expected
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_extract_code_fail(app: App) -> None:
     from nonebot_plugin_exe_code.matchers.depends import _extract_code
 
@@ -75,14 +73,13 @@ async def test_extract_code_fail(app: App) -> None:
         state = {}
         stack = AsyncExitStack()
 
-        with (
-            ensure_context(bot, event),
-            pytest.raises(ExceptionGroup),
-        ):
-            await dependent(bot=bot, event=event, state=state, stack=stack)
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                with pytest.raises(ExceptionGroup):
+                    await dependent(bot=bot, event=event, state=state, stack=stack)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_image_1(app: App) -> None:
     from nonebot_plugin_alconna.uniseg import Image
 
@@ -119,13 +116,14 @@ async def test_event_image_1(app: App) -> None:
         )
         state = {}
         stack = AsyncExitStack()
-        expected = Image(id="base64://" + base64.b64encode(fake_img_bytes).decode())
-        with ensure_context(bot, event):
-            result = await dependent(bot=bot, event=event, state=state, stack=stack)
-            assert result == expected
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                result = await dependent(bot=bot, event=event, state=state, stack=stack)
+        assert isinstance(result, Image)
+        assert result.url == f"base64://{base64.b64encode(fake_img_bytes).decode()}"
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_image_2(app: App) -> None:
     from nonebot_plugin_alconna.uniseg import Image
 
@@ -145,13 +143,15 @@ async def test_event_image_2(app: App) -> None:
         )
         state = {}
         stack = AsyncExitStack()
-        expected = Image(id="base64://" + base64.b64encode(fake_img_bytes).decode())
-        with ensure_context(bot, event):
-            result = await dependent(bot=bot, event=event, state=state, stack=stack)
-            assert result == expected
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                result = await dependent(bot=bot, event=event, state=state, stack=stack)
+
+        assert isinstance(result, Image)
+        assert result.url == f"base64://{base64.b64encode(fake_img_bytes).decode()}"
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_image_3(app: App) -> None:
     from nonebot_plugin_alconna.uniseg import Image
 
@@ -170,13 +170,15 @@ async def test_event_image_3(app: App) -> None:
         )
         state = {}
         stack = AsyncExitStack()
-        expected = Image(id="base64://" + base64.b64encode(b"\0\0\0").decode())
-        with ensure_context(bot, event):
-            result = await dependent(bot=bot, event=event, state=state, stack=stack)
-            assert result == expected
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                result = await dependent(bot=bot, event=event, state=state, stack=stack)
+
+        assert isinstance(result, Image)
+        assert result.url == f"base64://{base64.b64encode(b'\0\0\0').decode()}"
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_image_fail(app: App) -> None:
     from nonebot_plugin_exe_code.matchers.depends import _event_image
 
@@ -189,14 +191,13 @@ async def test_event_image_fail(app: App) -> None:
         )
         state = {}
         stack = AsyncExitStack()
-        with (
-            ensure_context(bot, event),
-            pytest.raises(BaseExceptionGroup),
-        ):
-            await dependent(bot=bot, event=event, state=state, stack=stack)
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                with pytest.raises(BaseExceptionGroup):
+                    await dependent(bot=bot, event=event, state=state, stack=stack)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_reply(app: App) -> None:
     from nonebot_plugin_alconna.uniseg import Reply as AlcReply
 
@@ -230,12 +231,13 @@ async def test_event_reply(app: App) -> None:
         state = {}
         stack = AsyncExitStack()
         expected = AlcReply(str(reply_obj.message_id), reply_msg, reply_obj)
-        with ensure_context(bot, event):
-            result = await dependent(bot=bot, event=event, state=state, stack=stack)
-            assert result == expected
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                result = await dependent(bot=bot, event=event, state=state, stack=stack)
+        assert result == expected
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_reply_fail(app: App) -> None:
     from nonebot_plugin_exe_code.matchers.depends import _event_reply
 
@@ -247,14 +249,13 @@ async def test_event_reply_fail(app: App) -> None:
         )
         state = {}
         stack = AsyncExitStack()
-        with (
-            ensure_context(bot, event),
-            pytest.raises(ExceptionGroup),
-        ):
-            await dependent(bot=bot, event=event, state=state, stack=stack)
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                with pytest.raises(ExceptionGroup):
+                    await dependent(bot=bot, event=event, state=state, stack=stack)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_reply_message_1(app: App) -> None:
     from nonebot_plugin_exe_code.matchers.depends import _event_reply_message
 
@@ -285,12 +286,13 @@ async def test_event_reply_message_1(app: App) -> None:
         )
         state = {}
         stack = AsyncExitStack()
-        with ensure_context(bot, event):
-            result = await dependent(bot=bot, event=event, state=state, stack=stack)
-            assert result == reply_msg
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                result = await dependent(bot=bot, event=event, state=state, stack=stack)
+        assert result == reply_msg
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_reply_message_2(app: App) -> None:
     from nonebot_plugin_exe_code.matchers.depends import _event_reply_message
 
@@ -321,12 +323,13 @@ async def test_event_reply_message_2(app: App) -> None:
         event.reply.message = reply_msg.extract_plain_text()  # pyright:ignore[reportAttributeAccessIssue]
         state = {}
         stack = AsyncExitStack()
-        with ensure_context(bot, event):
-            result = await dependent(bot=bot, event=event, state=state, stack=stack)
-            assert result == reply_msg
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                result = await dependent(bot=bot, event=event, state=state, stack=stack)
+        assert result == reply_msg
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_reply_message_fail_1(app: App) -> None:
     from nonebot_plugin_exe_code.matchers.depends import _event_reply_message
 
@@ -343,14 +346,13 @@ async def test_event_reply_message_fail_1(app: App) -> None:
         )
         state = {}
         stack = AsyncExitStack()
-        with (
-            ensure_context(bot, event),
-            pytest.raises(BaseExceptionGroup),
-        ):
-            await dependent(bot=bot, event=event, state=state, stack=stack)
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                with pytest.raises(BaseExceptionGroup):
+                    await dependent(bot=bot, event=event, state=state, stack=stack)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_event_reply_message_fail_2(app: App) -> None:
     from nonebot_plugin_exe_code.matchers.depends import _event_reply_message
 
@@ -380,8 +382,7 @@ async def test_event_reply_message_fail_2(app: App) -> None:
         )
         state = {}
         stack = AsyncExitStack()
-        with (
-            ensure_context(bot, event),
-            pytest.raises(ExceptionGroup),
-        ):
-            await dependent(bot=bot, event=event, state=state, stack=stack)
+        with ensure_v11_session_cache(bot, event):
+            async with ensure_context(bot, event):
+                with pytest.raises(BaseExceptionGroup):
+                    await dependent(bot=bot, event=event, state=state, stack=stack)
