@@ -1,7 +1,4 @@
-# ruff: noqa: S101
-
-import asyncio
-
+import anyio
 import pytest
 from nonebot.adapters.onebot.v11 import Message, MessageSegment
 from nonebot.adapters.onebot.v11.event import Reply, Sender
@@ -9,15 +6,17 @@ from nonebot.exception import FinishedException
 from nonebug import App
 
 from .conftest import exe_code_group, superuser
-from .fake.common import ensure_context, fake_img_bytes, fake_user_id
+from .fake.common import ensure_context, fake_img_bytes, fake_session, fake_user_id
 from .fake.onebot11 import (
+    ensure_v11_session_cache,
     fake_v11_bot,
-    fake_v11_event_session,
+    fake_v11_event,
     fake_v11_group_message_event,
+    make_v11_session_cache,
 )
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_getraw(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
     from nonebot_plugin_exe_code.matchers.getraw import matcher
@@ -42,25 +41,30 @@ async def test_getraw(app: App) -> None:
             ),
         )
         expected = Message(MessageSegment.text(str(reply_msg)))
-
+        cleanup = make_v11_session_cache(bot, event)
         ctx.receive_event(bot, event)
         ctx.should_pass_permission(matcher)
         ctx.should_call_send(event, expected)
         ctx.should_finished(matcher)
+    cleanup()
 
-    event, session = fake_v11_event_session(bot, superuser)
-    context = Context.get_context(session).ctx
-    gem = context.get("gem")
-    assert gem is not None, "Context variable `gem` not set"
-    assert gem == reply_msg, (
-        f"Context variable `gem` error: expect `{reply_msg}`, got `{gem}`"
-    )
+    async with app.test_matcher(matcher) as ctx:
+        bot = fake_v11_bot(ctx)
+        event = fake_v11_event(superuser)
+        with ensure_v11_session_cache(bot, event):
+            session = await fake_session(bot, event)
+            context = Context.get_context(session).ctx
+            gem = context.get("gem")
+            assert gem is not None, "Context variable `gem` not set"
+            assert gem == reply_msg, (
+                f"Context variable `gem` error: expect `{reply_msg}`, got `{gem}`"
+            )
 
-    gurl = context.get("gurl")
-    assert gurl is None, "Got unexpected variable `gurl`"
+            gurl = context.get("gurl")
+            assert gurl is None, "Got unexpected variable `gurl`"
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_getmid(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
     from nonebot_plugin_exe_code.matchers.getmid import matcher
@@ -86,24 +90,31 @@ async def test_getmid(app: App) -> None:
         )
         expected = Message("1")
 
+        cleanup = make_v11_session_cache(bot, event)
         ctx.receive_event(bot, event)
         ctx.should_pass_permission(matcher)
         ctx.should_call_send(event, expected)
         ctx.should_finished(matcher)
 
-    event, session = fake_v11_event_session(bot, superuser)
-    context = Context.get_context(session).ctx
-    gem = context.get("gem")
-    assert gem is not None, "Context variable `gem` not set"
-    assert gem == reply_msg, (
-        f"Context variable `gem` error: expect `{reply_msg}`, got `{gem}`"
-    )
+    cleanup()
 
-    gurl = context.get("gurl")
-    assert gurl is None, "Got unexpected variable `gurl`"
+    async with app.test_matcher(matcher) as ctx:
+        bot = fake_v11_bot(ctx)
+        event = fake_v11_event(superuser)
+        with ensure_v11_session_cache(bot, event):
+            session = await fake_session(bot, event)
+            context = Context.get_context(session).ctx
+            gem = context.get("gem")
+            assert gem is not None, "Context variable `gem` not set"
+            assert gem == reply_msg, (
+                f"Context variable `gem` error: expect `{reply_msg}`, got `{gem}`"
+            )
+
+            gurl = context.get("gurl")
+            assert gurl is None, "Got unexpected variable `gurl`"
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_getimg(app: App) -> None:
     import PIL.Image
 
@@ -119,8 +130,12 @@ async def test_getimg(app: App) -> None:
     getimg.image_fetch = image_fetch
 
     async def _test(varname: str | None = None) -> None:
-        reply_msg = "some" + MessageSegment.image(file=fake_img_bytes) + "text"
-        msg = MessageSegment.reply(1) + "getimg"
+        reply_msg = (
+            MessageSegment.text("some")
+            + MessageSegment.image(file=fake_img_bytes)
+            + MessageSegment.text("text")
+        )
+        msg = MessageSegment.reply(1) + MessageSegment.text("getimg")
         if varname is not None:
             msg += f" {varname}"
             msg.reduce()
@@ -145,6 +160,7 @@ async def test_getimg(app: App) -> None:
 
         async with app.test_matcher(matcher) as ctx:
             bot = fake_v11_bot(ctx)
+            cleanup = make_v11_session_cache(bot, event)
             ctx.receive_event(bot, event)
             ctx.should_pass_permission(matcher)
             if varname.isidentifier():
@@ -154,8 +170,13 @@ async def test_getimg(app: App) -> None:
             ctx.should_call_send(event, expected)
             ctx.should_finished(matcher)
 
+        cleanup()
+
         if varname.isidentifier():
-            event, session = fake_v11_event_session(bot, event.user_id)
+            event = fake_v11_event(event.user_id)
+            with ensure_v11_session_cache(bot, event):
+                session = await fake_session(bot, event)
+
             img = Context.get_context(session).ctx.get(varname)
             assert img is not None, f"Context variable `{varname}` not set for getimg"
             assert isinstance(img, PIL.Image.Image), (
@@ -170,7 +191,7 @@ async def test_getimg(app: App) -> None:
     getimg.image_fetch = _image_fetch
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_getimg_exception_1(app: App) -> None:
     from nonebot_plugin_exe_code.matchers import getimg
     from nonebot_plugin_exe_code.matchers.getimg import matcher
@@ -182,8 +203,12 @@ async def test_getimg_exception_1(app: App) -> None:
 
     getimg.image_fetch = image_fetch
 
-    reply_msg = "some" + MessageSegment.image(file=fake_img_bytes) + "text"
-    msg = MessageSegment.reply(1) + "getimg"
+    reply_msg = (
+        MessageSegment.text("some")
+        + MessageSegment.image(file=fake_img_bytes)
+        + MessageSegment.text("text")
+    )
+    msg = MessageSegment.reply(1) + MessageSegment.text("getimg")
     event = fake_v11_group_message_event(
         message=msg,
         user_id=superuser,
@@ -204,15 +229,17 @@ async def test_getimg_exception_1(app: App) -> None:
 
     async with app.test_matcher(matcher) as ctx:
         bot = fake_v11_bot(ctx)
+        cleanup = make_v11_session_cache(bot, event)
         ctx.receive_event(bot, event)
         ctx.should_pass_permission(matcher)
         ctx.should_call_send(event, expected)
         ctx.should_finished(matcher)
 
+    cleanup()
     getimg.image_fetch = _image_fetch
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_getimg_exception_2(app: App) -> None:
     from nonebot_plugin_exe_code.matchers import getimg
     from nonebot_plugin_exe_code.matchers.getimg import matcher
@@ -224,8 +251,12 @@ async def test_getimg_exception_2(app: App) -> None:
 
     getimg.image_fetch = image_fetch
 
-    reply_msg = "some" + MessageSegment.image(file=fake_img_bytes) + "text"
-    msg = MessageSegment.reply(1) + "getimg"
+    reply_msg = (
+        MessageSegment.text("some")
+        + MessageSegment.image(file=fake_img_bytes)
+        + MessageSegment.text("text")
+    )
+    msg = MessageSegment.reply(1) + MessageSegment.text("getimg")
     event = fake_v11_group_message_event(
         message=msg,
         user_id=superuser,
@@ -246,11 +277,13 @@ async def test_getimg_exception_2(app: App) -> None:
 
     async with app.test_matcher(matcher) as ctx:
         bot = fake_v11_bot(ctx)
+        cleanup = make_v11_session_cache(bot, event)
         ctx.receive_event(bot, event)
         ctx.should_pass_permission(matcher)
         ctx.should_call_send(event, expected)
         ctx.should_finished(matcher)
 
+    cleanup()
     getimg.image_fetch = _image_fetch
 
 
@@ -261,10 +294,10 @@ await feedback("test 2")
 """
 
 
-@pytest.mark.asyncio
-async def test_terminate(app: App) -> None:
+@pytest.mark.anyio
+async def test_terminate_1(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
-    from nonebot_plugin_exe_code.matchers.terminate import handle_terminate, matcher
+    from nonebot_plugin_exe_code.matchers.terminate import matcher
 
     async with app.test_matcher(matcher) as ctx:
         bot = fake_v11_bot(ctx)
@@ -273,11 +306,18 @@ async def test_terminate(app: App) -> None:
             user_id=superuser,
             message=Message("terminate"),
         )
-        with ensure_context(bot, event):
+        cleanup = make_v11_session_cache(bot, event)
+        async with ensure_context(bot, event):
             await Context.execute(bot, event, "")
         ctx.receive_event(bot, event)
         ctx.should_pass_permission(matcher)
         ctx.should_finished(matcher)
+    cleanup()
+
+
+@pytest.mark.anyio
+async def test_terminate_2(app: App) -> None:
+    from nonebot_plugin_exe_code.matchers.terminate import matcher
 
     async with app.test_matcher(matcher) as ctx:
         bot = fake_v11_bot(ctx)
@@ -285,7 +325,7 @@ async def test_terminate(app: App) -> None:
         event = fake_v11_group_message_event(
             group_id=exe_code_group,
             user_id=superuser,
-            message="terminate" + MessageSegment.at(target_id),
+            message=MessageSegment.text("terminate ") + MessageSegment.at(target_id),
         )
         ctx.receive_event(bot, event)
         ctx.should_pass_permission(matcher)
@@ -295,25 +335,39 @@ async def test_terminate(app: App) -> None:
             f"SessionNotInitialized: None, key=('{target_id}', '{bot.type}')",
         )
 
+
+@pytest.mark.anyio
+async def test_terminate_3(app: App) -> None:
+    from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.matchers.terminate import handle_terminate
+
     async with app.test_api() as ctx:
         bot = fake_v11_bot(ctx)
         user_id = fake_user_id()
-        event, _ = fake_v11_event_session(bot, user_id)
+        event = fake_v11_event(user_id)
+        cleanup = make_v11_session_cache(bot, event)
         ctx.should_call_send(event, Message("test 1"))
-        expected = "中止" + MessageSegment.at(user_id) + "的执行任务"
+        expected = (
+            MessageSegment.text("中止")
+            + MessageSegment.at(user_id)
+            + MessageSegment.text("的执行任务")
+        )
         ctx.should_call_send(event, expected)
 
         async def _test1() -> None:
-            with pytest.raises(asyncio.CancelledError):
+            with pytest.raises(anyio.get_cancelled_exc_class()):
                 await Context.execute(bot, event, code_test_terminate)
 
         async def _test2() -> None:
-            await asyncio.sleep(0.05)
+            await anyio.sleep(0.05)
             with pytest.raises(FinishedException):
                 await handle_terminate(
                     target=str(user_id),
                     context=Context.get_context(str(user_id)),
                 )
 
-        with ensure_context(bot, event):
-            await asyncio.gather(_test1(), _test2())
+        async with ensure_context(bot, event), anyio.create_task_group() as tg:
+            tg.start_soon(_test1)
+            tg.start_soon(_test2)
+
+    cleanup()
